<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>element</source>
        <comment>1</comment>
        <translation>Element</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>2-4</comment>
        <translation>Elemente</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>5+</comment>
        <translation>Elemente</translation>
    </message>
    <message>
        <source>item</source>
        <comment>1</comment>
        <translation>Eintrag</translation>
    </message>
    <message>
        <source>items</source>
        <comment>2-4</comment>
        <translation>Einträge</translation>
    </message>
    <message>
        <source>items</source>
        <comment>5+</comment>
        <translation>Einträge</translation>
    </message>
    <message>
        <source>complex item is not shown</source>
        <comment>1</comment>
        <translation>1</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>2-4</comment>
        <translation>2-4</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>5+</comment>
        <translation>5+</translation>
    </message>
    <message>
        <source>page</source>
        <comment>1</comment>
        <translation>Seite</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>2-4</comment>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>5+</comment>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>parameter</source>
        <comment>1</comment>
        <translation>Parameter</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>2-4</comment>
        <translation>Parameter</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>5+</comment>
        <translation>Parameter</translation>
    </message>
    <message>
        <source>child</source>
        <comment>1</comment>
        <translation>Nachfolger</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>2-4</comment>
        <translation>2-4</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>5+</comment>
        <translation>5+</translation>
    </message>
    <message>
        <source>Delinearization failed!</source>
        <translation>Entlinearisierung misslang!</translation>
    </message>
    <message>
        <source>Input file &apos;%1&apos; does not exist</source>
        <translation>Die Eingabedatei &apos;%1&apos; existiert nicht</translation>
    </message>
    <message>
        <source>Input and output files must be different</source>
        <translation>Eingabe- und Ausgabedatei müssen verschieden sein</translation>
    </message>
    <message>
        <source>Delinearized</source>
        <translation>Delinearisiert</translation>
    </message>
    <message>
        <source>Delinearize</source>
        <translation>Delinearisieren</translation>
    </message>
    <message>
        <source>Add item to dictionary</source>
        <translation>Einen Eintrag zum Verzeichnis hinzufügen</translation>
    </message>
    <message>
        <source>Add element to array</source>
        <translation>Ein Element zur Datenreihe hinzufügen</translation>
    </message>
    <message>
        <source>Set color</source>
        <translation>Setze Farbe</translation>
    </message>
    <message>
        <source>Set font properties</source>
        <translation>Setze Schrifteigenschaften</translation>
    </message>
    <message>
        <source>Set relative position of a single operator</source>
        <translation>Relative Position eines einzelnen Operators setzen</translation>
    </message>
    <message>
        <source>Set relative position</source>
        <translation>Setze relative Position</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <translation>Linienstrich-Stil setzen</translation>
    </message>
    <message>
        <source>Set line width</source>
        <translation>Setze Linie mit</translation>
    </message>
    <message>
        <source>View page</source>
        <translation>Seitenansicht</translation>
    </message>
    <message>
        <source>Add system font</source>
        <translation>Füge Systemschriftart hinzu</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <translation>Text ausschneiden</translation>
    </message>
    <message>
        <source>Set page tranformation matrix</source>
        <translation>Seitentransformationsmatrix setzen</translation>
    </message>
    <message>
        <source>Draw line</source>
        <translation>Linie zeichnen</translation>
    </message>
    <message>
        <source>Draw rect</source>
        <translation>Rechteck zeichnen</translation>
    </message>
    <message>
        <source>Add text</source>
        <translation>Text hinzufügen</translation>
    </message>
    <message>
        <source>Remove page</source>
        <translation>Seite entfernen</translation>
    </message>
    <message>
        <source>Show all operators</source>
        <translation>Alle Operatoren anzeigen</translation>
    </message>
    <message>
        <source>Show only text operators</source>
        <translation>Nur Textoperatoren anzeigen</translation>
    </message>
    <message>
        <source>Show only font operators</source>
        <translation>Nur Zeichenoperatoren anzeigen</translation>
    </message>
    <message>
        <source>Show only graphical operators</source>
        <translation>Nur Grafikoperatoren anzeigen</translation>
    </message>
    <message>
        <source>Move one level up</source>
        <translation>Eine Ebene höher</translation>
    </message>
    <message>
        <source>Move one level down</source>
        <translation>Eine Ebene tiefer</translation>
    </message>
    <message>
        <source>Save page as image</source>
        <translation>Seite als Grafik speichern</translation>
    </message>
    <message>
        <source>Save selected area as image</source>
        <translation>Ausgewählten Bereich als Grafik speichern</translation>
    </message>
    <message>
        <source>Changed revision to:</source>
        <translation>Überarbeitung geändert zu:</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Verwendung:</translation>
    </message>
    <message>
        <source>input file</source>
        <translation>Datei einfügen</translation>
    </message>
    <message>
        <source>output file</source>
        <translation>Ausgabedatei</translation>
    </message>
    <message>
        <source>Input file must exist</source>
        <translation>Die Eingabedatei muss existieren</translation>
    </message>
    <message>
        <source>Output file must not exist</source>
        <translation>Ausgabedatei darf nicht existieren</translation>
    </message>
    <message>
        <source>is expecting two parameters</source>
        <translation>erwartet zwei Parameter</translation>
    </message>
    <message>
        <source>Output file &apos;%1&apos; already exist</source>
        <translation>Ausgabedatei &apos;%1&apos; existiert bereits</translation>
    </message>
    <message>
        <source>position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>No page selected!</source>
        <translation>Keine Seite ausgewählt!</translation>
    </message>
    <message>
        <source>Page rotated.</source>
        <translation>Seite gedreht.</translation>
    </message>
    <message>
        <source>Change page rectangle</source>
        <translation>Seitenrechteck geändert</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Page metrics</source>
        <translation>Seitenmaße</translation>
    </message>
    <message>
        <source>Left upper corner</source>
        <translation>Linke obere Ecke</translation>
    </message>
    <message>
        <source>x position</source>
        <translation>x-Position</translation>
    </message>
    <message>
        <source>y position</source>
        <translation>y-Position</translation>
    </message>
    <message>
        <source>Right bottom corner</source>
        <translation>Rechte untere Ecke</translation>
    </message>
    <message>
        <source>MediaBox changed.</source>
        <translation>MediaBox geändert.</translation>
    </message>
    <message>
        <source>No page or operator selected!</source>
        <translation>Keine Seite oder Operateur ausgewählt!</translation>
    </message>
    <message>
        <source>Selected operator</source>
        <translation>Ausgewählter Operator</translation>
    </message>
    <message>
        <source>is not</source>
        <translation>ist nicht</translation>
    </message>
    <message>
        <source>suitable for colour setting.</source>
        <translation>geeignet für Farbauswahl.</translation>
    </message>
    <message>
        <source>Please see the pdf specification for details.</source>
        <translation>Bitte schauen Sie zu Details in die PDF-Spezifikationen.</translation>
    </message>
    <message>
        <source>changeable</source>
        <translation>änderbar</translation>
    </message>
    <message>
        <source>Colour changed</source>
        <translation>Farbe verändert</translation>
    </message>
    <message>
        <source>for</source>
        <translation>für</translation>
    </message>
    <message>
        <source>operators</source>
        <translation>Operatoren</translation>
    </message>
    <message>
        <source>suitable for line width change.</source>
        <translation>geeignet für Linie mit Änderung.</translation>
    </message>
    <message>
        <source>Line width changed.</source>
        <translation>Linienbreite verändert.</translation>
    </message>
    <message>
        <source>suitable for dash style change.</source>
        <translation>Geeignet für Wechsel des Strichstils.</translation>
    </message>
    <message>
        <source>Change line dash pattern</source>
        <translation>Linienstrichmuster ändern</translation>
    </message>
    <message>
        <source>Line dashing patterns</source>
        <translation>Linienstrichmuster</translation>
    </message>
    <message>
        <source>Solid line</source>
        <translation>durchgezogene Linie</translation>
    </message>
    <message>
        <source>Slightly dashed</source>
        <translation>Leicht gestrichelt</translation>
    </message>
    <message>
        <source>Dot and dashed</source>
        <translation>Punkt und Strich</translation>
    </message>
    <message>
        <source>Change effect</source>
        <translation>Effekt ändern</translation>
    </message>
    <message>
        <source>Global change</source>
        <translation>Allgemeine Änderung</translation>
    </message>
    <message>
        <source>Dash pattern changed.</source>
        <translation>Strichmuster geändert.</translation>
    </message>
    <message>
        <source>%1 added to page</source>
        <translation>%1 zur Seite hinzugefügt</translation>
    </message>
    <message>
        <source>Not valid</source>
        <translation>Nicht gültig</translation>
    </message>
    <message>
        <source>text operator</source>
        <translation>Textoperator</translation>
    </message>
    <message>
        <source>Only text operators allowed!</source>
        <translation>Nur Textoperatoren zulässig!</translation>
    </message>
    <message>
        <source>Operator %1 is not changeable</source>
        <translation>Operator %1 kann nicht verändert werden</translation>
    </message>
    <message>
        <source>Font changed.</source>
        <translation>Schriftart geändert.</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Schriftart hinzufügen</translation>
    </message>
    <message>
        <source>Add system fonts</source>
        <translation>Systemschriftart hinzufügen</translation>
    </message>
    <message>
        <source>Avaliable system fonts</source>
        <translation>Verfügbare Systemschriftarten</translation>
    </message>
    <message>
        <source>Select system Type1 font</source>
        <translation>Systemschriftart Typ 1 auswählen</translation>
    </message>
    <message>
        <source>System font added.</source>
        <translation>Systemschriftart hinzugefügt.</translation>
    </message>
    <message>
        <source>Text on page</source>
        <translation>Text in Seite</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Text extracted from page</source>
        <translation>Text aus der Seite ausgeschnitten</translation>
    </message>
    <message>
        <source>Text on a page.</source>
        <translation>Text auf eine Seite.</translation>
    </message>
    <message>
        <source>Page text displayed</source>
        <translation>Seitentext angezeigt</translation>
    </message>
    <message>
        <source>Add page transformation matrix</source>
        <translation>Seitentransformationsmatrix hinzufügen</translation>
    </message>
    <message>
        <source>Change page transformation matrix</source>
        <translation>Seitentransformationsmatrix ändern</translation>
    </message>
    <message>
        <source>Page transformation matrix description</source>
        <translation>Beschreibung der Seitentransformationsmatrix</translation>
    </message>
    <message>
        <source>Page transformation description</source>
        <translation>Beschreibung der Seitentransformationsmatrix</translation>
    </message>
    <message>
        <source>Select which transformations to use</source>
        <translation>Wählen welche Umformung benutzt werden soll</translation>
    </message>
    <message>
        <source>Translate (shift) page</source>
        <translation>Übersetze (shift) Seite</translation>
    </message>
    <message>
        <source>Scale page</source>
        <translation>Seite skalieren</translation>
    </message>
    <message>
        <source>Skew page</source>
        <translation>Seite schräg stellen</translation>
    </message>
    <message>
        <source>Page translation</source>
        <translation>Seite übersetzen</translation>
    </message>
    <message>
        <source>Set values</source>
        <translation>Werte setzen</translation>
    </message>
    <message>
        <source>Page scaling</source>
        <translation>Seite skalieren</translation>
    </message>
    <message>
        <source>Page skewing</source>
        <translation>Seite schräg stellen</translation>
    </message>
    <message>
        <source>Invalid number supplied.</source>
        <translation>Ungültige Nummer vorgegeben.</translation>
    </message>
    <message>
        <source>Page transformation matrix changed to </source>
        <translation>Änderung der Seitentransformationsmatrix zu</translation>
    </message>
    <message>
        <source>Change relative text operator position</source>
        <translation>Relative Textoperatorposition ändern</translation>
    </message>
    <message>
        <source>Change relative text position</source>
        <translation>Relative Textposition ändern</translation>
    </message>
    <message>
        <source>Relative operator position (this is not absolute position)</source>
        <translation>Relative Operatorposition (dies ist nicht die absolute Position)</translation>
    </message>
    <message>
        <source>Could not find text positioning.</source>
        <translation>Textpositionierung konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>Operator position changed.</source>
        <translation>Operatorposition geändert.</translation>
    </message>
    <message>
        <source>Relative operator position</source>
        <translation>Relative Operatorposition</translation>
    </message>
    <message>
        <source>X and Y position must be a number</source>
        <translation>X- und Y-Position müssen Zahlen sein</translation>
    </message>
    <message>
        <source>Line was drawn.</source>
        <translation>Linie wurde gezeichnet.</translation>
    </message>
    <message>
        <source>Rect was drawn.</source>
        <translation>Rechteck wurde gezeichnet.</translation>
    </message>
    <message>
        <source>Search text</source>
        <translation>Text suchen</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Finde</translation>
    </message>
    <message>
        <source>Text :</source>
        <translation>Text :</translation>
    </message>
    <message>
        <source>Find what</source>
        <translation>Suche was</translation>
    </message>
    <message>
        <source>On currently viewed page only</source>
        <translation>Nur auf der aktuell angezeigten Seite</translation>
    </message>
    <message>
        <source>Nothing was found.</source>
        <translation>Es wurde nichts gefunden.</translation>
    </message>
    <message>
        <source>Dictionary has no type!</source>
        <translation>Verzeichnis hat keine Typ!</translation>
    </message>
    <message>
        <source>Maybe bad stream!</source>
        <translation>Möglicherweise ein schlechter Datenstrom!</translation>
    </message>
    <message>
        <source>%1 is requirement for %2, but not found for it !</source>
        <translation>%1 ist erforderlich für %2, aber für es nicht gefunden worden !</translation>
    </message>
    <message>
        <source>For child %1 of %2 is requirement %3 subchild, but has %4</source>
        <translation>Für Kind %1 von %2 ist erforderlich %3 Kindeskind, aber es hat %4 </translation>
    </message>
    <message>
        <source>Available functions:</source>
        <translation>Verfügbare Funktionen:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parameter</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>No function found matching &apos;%1&apos;</source>
        <translation>Keine zu &apos;%1&apos;passende Funktion gefunden</translation>
    </message>
    <message>
        <source>Too many function found matching &apos;%1&apos;</source>
        <translation>Zu viele zu &apos;%1&apos; passende Funktionen gefunden</translation>
    </message>
    <message>
        <source>Matching functions</source>
        <translation>passende Funktionen</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Laufend</translation>
    </message>
    <message>
        <source>function name</source>
        <translation>Funktionsname</translation>
    </message>
    <message>
        <source>function parameter(s)</source>
        <translation>Funktionsparameter</translation>
    </message>
    <message>
        <source>First parameter is name of function to invoke (case insensitive) or its unambiguous part.</source>
        <translation>Erster Parameter ist der Name der aufzurufenden Funktion (unterscheidet Groß- und Kleinschreibung) oder sein unzweideutiger Teil.</translation>
    </message>
    <message>
        <source>Rest of parameters are passed to invoked function.</source>
        <translation>Rest der Parameter werden übergeben an die aufzurufende Funktion.</translation>
    </message>
    <message>
        <source>New revision of document created</source>
        <translation>Eine neue Revision des Dokuments wurde erstellt</translation>
    </message>
    <message>
        <source>Saving as</source>
        <translation type="obsolete">Speicher als</translation>
    </message>
    <message>
        <source>Warning: This document is linearized PDF!</source>
        <translation>Warnung: Dieses Dokument ist linearisiertes PDF!</translation>
    </message>
    <message>
        <source>Warning: This document is encrypted!</source>
        <translation>Warnung: Dieses Dokument ist verschlüsselt!</translation>
    </message>
    <message>
        <source>Encryption filter:</source>
        <translation type="obsolete">Entschlüsselungsfilter:</translation>
    </message>
    <message>
        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
        <translation type="obsolete">Verschlüsselter Inhalt wird als Datenmüll erscheinen und viele Operationen werden unmöglich sein</translation>
    </message>
    <message>
        <source>Error occured while loading file</source>
        <translation>Beim Landen der Datei trat ein Fehler auf</translation>
    </message>
    <message>
        <source>Image was not saved!</source>
        <translation>Das Abbild wurde nicht gespeichert!</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation>nicht im zulässigen Bereich</translation>
    </message>
    <message>
        <source>Operator cm must have array with 6 numbers as parameter!</source>
        <translation>Operator cm braucht ein Datenfeld mit 6 Zahlen als Parameter!</translation>
    </message>
    <message>
        <source>Matrix is in bad state !</source>
        <translation>Matrix ist in einem schlechten Zustand !</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have 1 parameter, but has %2 !</source>
        <translation>Operator &apos;%1&apos; sollte 1 Parameter haben, hat aber %2 !</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have %2 parameters, but has %3 !</source>
        <translation>Operator &apos;%1&apos; sollte %2 Parameter haben, hat aber %3 !</translation>
    </message>
    <message>
        <source>Operator must be</source>
        <translation>Operator muss sein</translation>
    </message>
    <message>
        <source>Must define color</source>
        <translation>Eine Farbe muss vorgegeben werden</translation>
    </message>
    <message>
        <source>r,g,b must be number</source>
        <translation>r,g,b müssen Zahlen sein</translation>
    </message>
    <message>
        <source>r,g,b must be from 0 to 255</source>
        <translation>r,g.b müssen von 0 bis 255 sein</translation>
    </message>
    <message>
        <source>No preceding font operator found...</source>
        <translation>Keinen angegebenen Schriftoperator gefunden...</translation>
    </message>
    <message>
        <source>Invalid operand type</source>
        <translation>Ungültiger Operandentyp</translation>
    </message>
    <message>
        <source>Page parameter must be defined!</source>
        <translation>Seitenparameter müssen definiert werden!</translation>
    </message>
    <message>
        <source>This option is not supported.</source>
        <translation>Diese Option wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>&amp;Add object</source>
        <translation>&amp;Objekt hinzufügen</translation>
    </message>
    <message>
        <source>Add and c&amp;lose</source>
        <translation>Hinzufügen und c&amp;lose</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation>Überschreiben?</translation>
    </message>
    <message>
        <source>Document is read-only</source>
        <translation>Dokument kann nur gelesen werden</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Anwenden</translation>
    </message>
    <message>
        <source>Open file ...</source>
        <translation>Datei öffnen ...</translation>
    </message>
    <message>
        <source>PDF files (*.pdf)</source>
        <translation>PDF Dateien (*.pdf)</translation>
    </message>
    <message>
        <source>File called &quot;%1&quot; already exists. Do you want to overwrite it?</source>
        <translation>Datei mit dem Namen &quot;%1&quot; existiert bereits. Wollen Sie diese überschreiben?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Save file as ...</source>
        <translation>Speichern als ...</translation>
    </message>
    <message>
        <source>xml files (*.xml)</source>
        <translation>xml Dateien (*.xml)</translation>
    </message>
    <message>
        <source>Pick a file ...</source>
        <translation>Wählen Sie eine Datei ...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Öffnen</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>&amp;nach oben</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>&amp;nach unten</translation>
    </message>
    <message>
        <source>&amp;Index</source>
        <translation>&amp;Index</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>&lt;no name&gt;</source>
        <translation>&lt;kein Name&gt;</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <source>Dictionary</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <source>Stream</source>
        <translation>Datenstrom</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Anmerkung</translation>
    </message>
    <message>
        <source>List</source>
        <translation>LIste</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Content Stream</source>
        <translation>Inhaltsdatenstrom</translation>
    </message>
    <message>
        <source>Showing all</source>
        <comment>mode</comment>
        <translation>Alle anzeigen</translation>
    </message>
    <message>
        <source>Showing text. op.</source>
        <comment>mode</comment>
        <translation>Text. Op. anzeigen.</translation>
    </message>
    <message>
        <source>Showing font. op.</source>
        <comment>mode</comment>
        <translation>Schrift Op. anzeigen.</translation>
    </message>
    <message>
        <source>Showing graphic. op.</source>
        <comment>mode</comment>
        <translation>Grafik-Op. anzeigen.</translation>
    </message>
    <message>
        <source>Parameter</source>
        <translation>Parameter</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Operators</source>
        <translation>Operatoren</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anmerkungen</translation>
    </message>
    <message>
        <source>Invalid operation</source>
        <translation>Unzulässige Operation</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Null Pointer Access in</translation>
    </message>
    <message>
        <source>Null</source>
        <comment>Type name</comment>
        <translation>Null</translation>
    </message>
    <message>
        <source>Bool</source>
        <comment>Type name</comment>
        <translation>Bool</translation>
    </message>
    <message>
        <source>Int</source>
        <comment>Type name</comment>
        <translation>Int</translation>
    </message>
    <message>
        <source>Real</source>
        <comment>Type name</comment>
        <translation>Real</translation>
    </message>
    <message>
        <source>String</source>
        <comment>Type name</comment>
        <translation>String</translation>
    </message>
    <message>
        <source>Name</source>
        <comment>Type name</comment>
        <translation>Name</translation>
    </message>
    <message>
        <source>Ref</source>
        <comment>Type name</comment>
        <translation>Ref</translation>
    </message>
    <message>
        <source>Array</source>
        <comment>Type name</comment>
        <translation>Array</translation>
    </message>
    <message>
        <source>Dict</source>
        <comment>Type name</comment>
        <translation>Dict</translation>
    </message>
    <message>
        <source>Stream</source>
        <comment>Type name</comment>
        <translation>Stream (Datenstrom)</translation>
    </message>
    <message>
        <source>DebugCmd</source>
        <comment>Type name</comment>
        <translation>DebugCmd</translation>
    </message>
    <message>
        <source>DebugError</source>
        <comment>Type name</comment>
        <translation>DebugError</translation>
    </message>
    <message>
        <source>DebugEOF</source>
        <comment>Type name</comment>
        <translation>DebugEOF</translation>
    </message>
    <message>
        <source>DebugNone</source>
        <comment>Type name</comment>
        <translation>DebugNone</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>Fatal Error</source>
        <translation>Schwerer Fehler</translation>
    </message>
    <message>
        <source>Invalid %1 in config:
Name: %2
Data: %3
</source>
        <translation>Ungültige %1 in der Konfiguration:
Name: %2
Daten: %3</translation>
    </message>
    <message>
        <source>Expected: </source>
        <translation>Erwartet:</translation>
    </message>
    <message>
        <source>Missing item in config</source>
        <translation>Fehlender Eintrag in der Konfiguration</translation>
    </message>
    <message>
        <source>menu definition</source>
        <translation>Menüdefinition</translation>
    </message>
    <message>
        <source>Menu items list</source>
        <translation>Liste der Menüelemente</translation>
    </message>
    <message>
        <source>Cycle in menu detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>menu item</source>
        <translation>Menüelemente</translation>
    </message>
    <message>
        <source>2 or more parameters in item definition</source>
        <translation>2 oder mehr Parameter in Definition des Eintrags</translation>
    </message>
    <message>
        <source>toolbar item</source>
        <translation>Werkzeugleistenelement</translation>
    </message>
    <message>
        <source>4 parameters in item definition</source>
        <translation>4 Parameter in der Definition des Eintrags</translation>
    </message>
    <message>
        <source>label item</source>
        <translation>Beschriftung des Eintrags</translation>
    </message>
    <message>
        <source>toolbar definition</source>
        <translation>Definition der Werkzeugleiste</translation>
    </message>
    <message>
        <source>Options: </source>
        <translation>Optionen:</translation>
    </message>
    <message>
        <source>Parameter missing for option : </source>
        <translation>Für die Option fehlt ein Parameter:</translation>
    </message>
    <message>
        <source>Invalid commandline option : </source>
        <translation>ungültige Kommandozeilenoption :</translation>
    </message>
    <message>
        <source>option(s)</source>
        <translation>Option(en)</translation>
    </message>
    <message>
        <source>files(s)</source>
        <translation>Datei(en)</translation>
    </message>
    <message>
        <source>Print help and exit</source>
        <translation>Hilfe anzeigen und beenden</translation>
    </message>
    <message>
        <source>Print version and exit</source>
        <translation>Version anzeigen und beenden</translation>
    </message>
    <message>
        <source>Set debug messages verbosity</source>
        <translation>Setzte Debugmeldungen auf umfangreich</translation>
    </message>
    <message>
        <source>(n = -1 .. 5)</source>
        <translation>(n=-1 .. 5)</translation>
    </message>
    <message>
        <source>Run in commandline mode</source>
        <translation>Im Kommandozeilenmodus ausführen</translation>
    </message>
    <message>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Run script from script path or current directory if not found</source>
        <translation>Starte das Skript aus dem Skript-Path oder, falls nicht gefunden, aus dem aktuellen Verzeichnis</translation>
    </message>
    <message>
        <source>Run script from current directory</source>
        <translation>Starte das Skript aus dem aktuellen Verzeichnis</translation>
    </message>
    <message>
        <source>code</source>
        <translation>Kode</translation>
    </message>
    <message>
        <source>Evaluate script code</source>
        <translation>Werte den Skriptcode aus</translation>
    </message>
    <message>
        <source>Shortcut for</source>
        <translation>Abkürzung für</translation>
    </message>
    <message>
        <source>Stop processing options</source>
        <translation>Verarbeitung der Optionen anhalten</translation>
    </message>
    <message>
        <source>Text saved to %1</source>
        <translation>Text gesichert in %1</translation>
    </message>
    <message>
        <source>Save as text file</source>
        <translation>Als Textdatei sichern</translation>
    </message>
    <message>
        <source>Font face</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Font size (in points)</source>
        <translation>Schriftgröße (in Punkten)</translation>
    </message>
    <message>
        <source>Line width (in points)</source>
        <translation>Linienweite (in Punkten)</translation>
    </message>
    <message>
        <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
        <translation>Benutzen Sie &apos;%1 --help&apos;, um eine Liste Kommandozeilenoptionen und ihren Parametern zu sehen</translation>
    </message>
    <message>
        <source>Saved as</source>
        <translation>Gespeichert als</translation>
    </message>
    <message>
        <source>Unable to open file: %1</source>
        <translation>Außerstande, Datei: %1 zu öffnen</translation>
    </message>
    <message>
        <source>Not implemented: %1</source>
        <translation>Nicht implementiert: %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Apply from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many pages</source>
        <translation>Wieviele Seiten</translation>
    </message>
    <message>
        <source>Flattening failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flattened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No pages in document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation not implemented: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>annotation_type</name>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>FreeText</source>
        <translation>Freier Text</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Quadrat</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Kreis</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Vieleck</translation>
    </message>
    <message>
        <source>PolyLine</source>
        <translation>Vielecklinie</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Hervorhebung</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstreichung</translation>
    </message>
    <message>
        <source>Squiggly</source>
        <translation>verschnörkelt</translation>
    </message>
    <message>
        <source>StrikeOut</source>
        <translation>Streichen</translation>
    </message>
    <message>
        <source>Stamp</source>
        <translation>Kennzeichnen</translation>
    </message>
    <message>
        <source>Caret</source>
        <translation>Exponentialzeichen</translation>
    </message>
    <message>
        <source>Ink</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Popup</source>
        <translation>Aufklappen</translation>
    </message>
    <message>
        <source>Fileattachement</source>
        <translation>Dateianhang</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Klang</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Widget</source>
        <translation>Widget</translation>
    </message>
    <message>
        <source>Screen</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <source>Printermark</source>
        <translation>Druckermarkierung</translation>
    </message>
    <message>
        <source>Trapnet</source>
        <translation>Trapnet</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Wasserzeichen</translation>
    </message>
    <message>
        <source>3D</source>
        <translation>3D</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>gui::AboutWindow</name>
    <message>
        <source>About program</source>
        <translation>Über das Programm</translation>
    </message>
    <message>
        <source>Free program for PDF document manipulation</source>
        <translation>Freies Programm zum Bearbeiten von PDF Dokumenten</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Project page</source>
        <translation>Projektseite</translation>
    </message>
    <message>
        <source>Compiled</source>
        <translation>Kompiliert</translation>
    </message>
    <message>
        <source>Using Qt %1</source>
        <translation>Mit QT%1</translation>
    </message>
    <message>
        <source>, QSA %1</source>
        <translation>, QSA%1</translation>
    </message>
    <message>
        <source>This program is distributed under terms of GNU GPL</source>
        <translation>Dieses Programm wird unter den Bedingungen der GNU GPL verteilt</translation>
    </message>
</context>
<context>
    <name>gui::AddItemDialog</name>
    <message>
        <source>Add object</source>
        <translation>Objekt hinzufügen</translation>
    </message>
    <message>
        <source>Type and value of new object</source>
        <translation>Typ und Wert des neuen Objektes</translation>
    </message>
    <message>
        <source>New empty Dictionary</source>
        <translation>Neues leeres Verzeichnis</translation>
    </message>
    <message>
        <source>New empty Array</source>
        <translation>Neues leeres Feld</translation>
    </message>
    <message>
        <source>Property name</source>
        <translation>Bezeichnung der Eigenschaft</translation>
    </message>
    <message>
        <source>Add to position</source>
        <translation>An der Stelle hinzufügen</translation>
    </message>
    <message>
        <source>Append to end</source>
        <translation>Am Ende anhängen</translation>
    </message>
    <message>
        <source>No object type selected</source>
        <translation>Kein Objekt-Typ ausgewählt</translation>
    </message>
    <message>
        <source>Entered property is not valid</source>
        <translation>Die eingetragene Eigenschaft ist nicht gültig</translation>
    </message>
    <message>
        <source>Name of new property must be specified</source>
        <translation>Die Bezeichnung einer neuen Eigenschaft muss vorgegeben werden</translation>
    </message>
    <message>
        <source>Reference target does not exist!</source>
        <translation>Aufgerufenes Ziel existiert nicht!</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; already exist as %2</source>
        <translation>Eigenschaft&apos;%1&apos;existiert bereits als %2</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; added to dictionary</source>
        <translation>Eigenschaft &apos;%1&apos; zum Verzeichnis hinzugefügt</translation>
    </message>
    <message>
        <source>Property added to position %1 in array</source>
        <translation>Eigenschaft an Position %1 dem Bereich hinzugefügt</translation>
    </message>
    <message>
        <source>Array index %1 out of range</source>
        <translation>Index des Bereichs %1 nicht im zulässigen Bereich</translation>
    </message>
    <message>
        <source>Property added to end of array</source>
        <translation>Eigenschaft am Ende des Bereichs hinzugefügt</translation>
    </message>
</context>
<context>
    <name>gui::AnnotDialog</name>
    <message>
        <source>Add new annotation</source>
        <translation>Neuen Kommentar hinzugefügt</translation>
    </message>
    <message>
        <source>Text Annotation</source>
        <translation>Text-Anmerkung</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Öffnen</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Icon &amp;Name</source>
        <translation>Symbol &amp;Name</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Anmerkung</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <source>NewParagraph</source>
        <translation>Neuer Absatz</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notiz</translation>
    </message>
    <message>
        <source>Paragraph</source>
        <translation>Absatz</translation>
    </message>
    <message>
        <source>&amp;State</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <source>Marked</source>
        <translation>gekennzeichnet</translation>
    </message>
    <message>
        <source>Unmarked</source>
        <translation>nicht gekennzeichnet</translation>
    </message>
    <message>
        <source>State &amp;Model</source>
        <translation>Status &amp;Typ</translation>
    </message>
    <message>
        <source>Review</source>
        <translation>Änderung</translation>
    </message>
    <message>
        <source>&amp;Text Annotation</source>
        <translation>&amp;Text-Anmerkung</translation>
    </message>
    <message>
        <source>&amp;Destination</source>
        <translation>&amp;Ziel</translation>
    </message>
    <message>
        <source>&amp;Highlight mode</source>
        <translation>&amp;Hervorhebungsmodus</translation>
    </message>
    <message>
        <source>N - None</source>
        <translation>N - Kein</translation>
    </message>
    <message>
        <source>I - Invert</source>
        <translation>I - Umkehren</translation>
    </message>
    <message>
        <source>O - Outline</source>
        <translation>O - Skizze</translation>
    </message>
    <message>
        <source>P - Push</source>
        <translation>P - Durchführen</translation>
    </message>
    <message>
        <source>&amp;Link Annotation</source>
        <translation>&amp;Link Anmerkung</translation>
    </message>
</context>
<context>
    <name>gui::Base</name>
    <message>
        <source>Error running</source>
        <translation>Fehlerlauf</translation>
    </message>
    <message>
        <source>Script not found</source>
        <translation>Skript nicht gefunden</translation>
    </message>
    <message>
        <source>No init script found - check your configuration</source>
        <translation>Kein Initialisierungs-Skript gefunden - überprüfen Sie Ihre Konfiguration</translation>
    </message>
    <message>
        <source>Looked for</source>
        <comment>scripts</comment>
        <translation>Suchen nach</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Flattening of encrypted documents is not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearization of encrypted documents is not supported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::BaseCore</name>
    <message>
        <source>Error in callback handler: </source>
        <translation>Fehler im Rückfrage-Steuerungsprogramm:</translation>
    </message>
    <message>
        <source>Exception in callback handler: </source>
        <translation>Ausnahme im Rückrufbehandler:</translation>
    </message>
    <message>
        <source>Unknown exception in script occured</source>
        <translation>Unbekannter Fehler tauchte im Skript auf</translation>
    </message>
    <message>
        <source>In script</source>
        <translation>Im Skript</translation>
    </message>
    <message>
        <source>line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Null-Pointer Access in</translation>
    </message>
    <message>
        <source>Exception in </source>
        <translation>Ausnahme in</translation>
    </message>
    <message>
        <source>Invalid object given for parameter %1 in </source>
        <translation>Ungültiges Objekt vorgegeben für Parameter %1 in</translation>
    </message>
    <message>
        <source>Expected</source>
        <comment>object type</comment>
        <translation>Erwartet</translation>
    </message>
    <message>
        <source>Got</source>
        <comment>object type</comment>
        <translation>geholt</translation>
    </message>
</context>
<context>
    <name>gui::BaseGUI</name>
    <message>
        <source>No document opened</source>
        <translation>Kein Dokument geöffnet</translation>
    </message>
    <message>
        <source>You must pick a different file than &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::ColorTool</name>
    <message>
        <source>Choose color</source>
        <translation>Wählen Sie die Farbe</translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation>Vordergrund</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
</context>
<context>
    <name>gui::HelpWindow</name>
    <message>
        <source>help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>gui::MergeDialog</name>
    <message>
        <source>Open file with pages to be inserted</source>
        <translation>Datei öffnen mit den einzufügenden Seiten</translation>
    </message>
    <message>
        <source>Insert pages from another document</source>
        <translation>Seiten aus einem anderen Dokument einfügen</translation>
    </message>
    <message>
        <source>&amp;Filename</source>
        <translation>&amp;Dateiname</translation>
    </message>
    <message>
        <source>END</source>
        <comment>end of document marker</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::MultiTreeWindow</name>
    <message>
        <source>Tree</source>
        <translation>Strukturbaum</translation>
    </message>
    <message>
        <source>Document tree</source>
        <translation>Strukturbaum des Dokuments</translation>
    </message>
    <message>
        <source>Close current tab</source>
        <translation>Aktuelle Registerkarte schließen</translation>
    </message>
    <message>
        <source>Switch to ...</source>
        <translation>Wechseln zu ...</translation>
    </message>
</context>
<context>
    <name>gui::OptionWindow</name>
    <message>
        <source>options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Advanced mode</source>
        <translation>Erweiterter Modus</translation>
    </message>
    <message>
        <source>Turning on advanced mode will allow more powerful (but also more dangerous) changes to edited document.</source>
        <translation>Das Einstellen des erweiterten Modus erlaubt leistungsfähigere (aber auch gefährlichere) Änderungen in der Bearbeitung des Dokumentes.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Advanced mode will affect only newly opened files</source>
        <translation>&lt;b&gt;Anmerkung&lt;/b&gt;: Wechsel zum Erweiterten Modus hat nur Einfluß auf neu geöffnete Dateien</translation>
    </message>
    <message>
        <source>Show hidden properties</source>
        <translation>Zeige versteckte Eigenschaften</translation>
    </message>
    <message>
        <source>Allow editing read-only properties</source>
        <translation>Erlaube das Bearbeiten von Eigenschaften, die nur gelesen werden können</translation>
    </message>
    <message>
        <source>Remember path of last opened/saved file</source>
        <translation>Pfad zur zuletzt geöffneten/gespeicherten Datei merken </translation>
    </message>
    <message>
        <source>Length units</source>
        <translation>Längen Einheiten</translation>
    </message>
    <message>
        <source>Character encoding</source>
        <translation>Zeichencodierung</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Pfade</translation>
    </message>
    <message>
        <source>You can use environment variables (for example $HOME) in settings on this page</source>
        <translation>Sie können Umgebungsvariablen (z.B. $HOME) in den Einstellung auf dieser Seite benutzen</translation>
    </message>
    <message>
        <source>Icon Path</source>
        <translation>Symbol-Pfad</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Icon Path will take effect on next program start</source>
        <translation>&lt;b&gt;Anmerkung&lt;/b&gt;: Änderung des Symbolpfades hat Auswirkungen beim nächsten Start des Programms</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Skript-Pfad</translation>
    </message>
    <message>
        <source>Scripts to run on start</source>
        <translation>Skript, das beim Start ausgeführt wird</translation>
    </message>
    <message>
        <source>Console log file</source>
        <translation>Konsolen Protokolldatei</translation>
    </message>
    <message>
        <source>Object tree</source>
        <translation>Objektbaum</translation>
    </message>
    <message>
        <source>These objects will be shown in the object tree</source>
        <translation>Diese Objekte werden im Objektbaum angezeigt</translation>
    </message>
    <message>
        <source>Document dictionary</source>
        <translation>Dokumenten-Verzeichnis</translation>
    </message>
    <message>
        <source>Object dictionaries</source>
        <translation>Objektverzeichnis</translation>
    </message>
    <message>
        <source>Graphic objects</source>
        <translation>Grafikobjekt</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anmerkung</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Umrisse</translation>
    </message>
    <message>
        <source>Content Streams</source>
        <translation>Datenstrom des Inhalts</translation>
    </message>
    <message>
        <source>Simple Objects</source>
        <translation>Einfache Objekte</translation>
    </message>
    <message>
        <source>Options affecting object tree and property editor</source>
        <translation>Optionen wirken sich auf den Objektbaum und die Eigenschaftsbearbeitung aus</translation>
    </message>
    <message>
        <source>Sort dictionary items alphabetically</source>
        <translation>Ordne die Verzeichniseinträge alphabetisch</translation>
    </message>
    <message>
        <source>Commandline</source>
        <translation>Kommandozeile</translation>
    </message>
    <message>
        <source>Commandline options</source>
        <translation>Kommandozeilenoptionen</translation>
    </message>
    <message>
        <source>Show return value of executed scripts in console</source>
        <translation>Zeige die Rückgabewerte der in der Konsole ausgeführten Skripte an</translation>
    </message>
    <message>
        <source>Show return value also for complex types
(possibly long output)</source>
        <translation>Zeige die Rückgabewerte auch für komplexe Arten an
(möglicher Weise lange Ausgabe)</translation>
    </message>
    <message>
        <source>Show errors from event handlers</source>
        <translation>Zeige Fehler des Ereignisbehandlers an</translation>
    </message>
    <message>
        <source>Show command editor</source>
        <translation>Zeige den Kommandoeditor an</translation>
    </message>
    <message>
        <source>Show command line</source>
        <translation>Zeige die Kommandozeile an</translation>
    </message>
    <message>
        <source>Editable command line</source>
        <translation>Bearbeitbare Kommandozeile</translation>
    </message>
    <message>
        <source>History options</source>
        <translation>Historienoptionen</translation>
    </message>
    <message>
        <source>History file</source>
        <translation>Historiendatei</translation>
    </message>
    <message>
        <source>Max. lines in history</source>
        <translation>Max. Zeilen in der Historie</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Werkzeugleisten</translation>
    </message>
    <message>
        <source>These toolbars will be shown:</source>
        <translation>Diese Werkzeugleisten werden angezeigt:</translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation>Aussehen und Handhabung</translation>
    </message>
    <message>
        <source>You can set fonts used in application</source>
        <translation>Sie können die die in der Anwendung benutzten Schriftarten setzen</translation>
    </message>
    <message>
        <source>Application font</source>
        <translation>Schriftart der Anwendung</translation>
    </message>
    <message>
        <source>Console font</source>
        <translation>Schriftart der Konsole</translation>
    </message>
    <message>
        <source>Statusbar font</source>
        <translation>Statusleiste Schriftart</translation>
    </message>
    <message>
        <source>You can specify overall visual style</source>
        <translation>Sie können den globalen Stil der Ansicht bestimmen</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Symbolstil</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing icon theme will take effect on next program start</source>
        <translation>&lt;b&gt;Anmerkung&lt;/b&gt;: Der Wechsel des Symbolstils wirkt sich erst nach dem nächsten Programmstart aus</translation>
    </message>
    <message>
        <source>Use big icons</source>
        <translation>Verwende große Symbole</translation>
    </message>
    <message>
        <source>Page view</source>
        <translation>Seitenansicht</translation>
    </message>
    <message>
        <source>Command Line</source>
        <translation>Kommandozeile</translation>
    </message>
    <message>
        <source>Initial focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will specify which part of editor window will receive keyboard focus when new window is opened</source>
        <translation>Dies bestimmt, welcher Teil des Bearbeitungsfensters den Tastaturfocus erhält, wenn ein neues Fenster geöffnet wird</translation>
    </message>
</context>
<context>
    <name>gui::PageSpace</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 von %2</translation>
    </message>
    <message>
        <source>Resizing zone must be positive integer or null !</source>
        <translation type="obsolete">Skalierungsbereich muss positiv ganzzahlig oder Null sein !</translation>
    </message>
    <message>
        <source>Save as image ...</source>
        <translation>Speichere als Bild ...</translation>
    </message>
</context>
<context>
    <name>gui::PasswordDialog</name>
    <message>
        <source>Enter password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PdfEditWindow</name>
    <message>
        <source>Selection</source>
        <translation>Auswahl</translation>
    </message>
    <message>
        <source>Selected operators</source>
        <translation>Ausgewählte Operatoren</translation>
    </message>
    <message>
        <source>Selected annotations</source>
        <translation>Ausgewählte Anmerkungen</translation>
    </message>
    <message>
        <source>Current file is not saved. Do you want to save it?</source>
        <translation>Die aktuelle Datei ist nicht gesichert. Wollen Sie sie speichern?</translation>
    </message>
    <message>
        <source>No document to save</source>
        <translation>Kein Dokument zu Speichern</translation>
    </message>
    <message>
        <source>Name is empty</source>
        <translation>Die Bezeichnung ist leer</translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Das Dokument befindet sich nur im Lesemodus</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Ein unbekannter Fehler trat während des Speicherns des Dokuments auf</translation>
    </message>
    <message>
        <source>viewing revision</source>
        <translation>Änderung der Ansicht</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>Linearisiertes PDF</translation>
    </message>
    <message>
        <source>Encrypted</source>
        <translation>Verschlüsselt</translation>
    </message>
    <message>
        <source>Error while loading document </source>
        <translation>Ein Fehler trat beim Laden des Dokumentes auf</translation>
    </message>
    <message>
        <source>Unknown error while loading document </source>
        <translation>Ein unbekannter Fehler trat während des Ladens des Dokumentes auf</translation>
    </message>
    <message>
        <source>Loaded file</source>
        <translation>Datei geladen</translation>
    </message>
    <message>
        <source>Saving not implemented:
%1</source>
        <translation>Speichern nicht implementiert:
%1</translation>
    </message>
    <message>
        <source>Error occured while saving copy:
%1</source>
        <translation>Ein Fehler trat während des Speichern einer Kopie auf:
%1</translation>
    </message>
    <message>
        <source>Password entered for document is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Property</name>
    <message>
        <source>Read only</source>
        <translation>Nur Lesen</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
</context>
<context>
    <name>gui::PropertyEditor</name>
    <message>
        <source>No object selected</source>
        <translation>Kein Objekt ausgewählt</translation>
    </message>
    <message>
        <source>This %1 is empty</source>
        <translation>Dies %1 ist leer</translation>
    </message>
    <message>
        <source>dictionary</source>
        <comment>property type</comment>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <source>This %1 does not have any directly editable properties</source>
        <translation>Dies %1 hat keine direkt bearbeitbaren Eigenschaften</translation>
    </message>
    <message>
        <source>stream</source>
        <comment>property type</comment>
        <translation>Datenstrom</translation>
    </message>
    <message>
        <source>This array is empty</source>
        <translation>Dieses Feld ist leer</translation>
    </message>
    <message>
        <source>This array does not have any directly editable elements</source>
        <translation>Dieses Feld hat keine direkt bearbeitbaren Elemente</translation>
    </message>
    <message>
        <source>This type of object does not have any properties</source>
        <translation>Dieser Objekttyp hat keine Eigenschaften</translation>
    </message>
    <message>
        <source>This operator does not have any parameters</source>
        <translation>Dieser Operateur hat keine Parameter</translation>
    </message>
    <message>
        <source>This operator does not have any directly editable parameters</source>
        <translation>Kein Objekt ausgewählt</translation>
    </message>
</context>
<context>
    <name>gui::QSPage</name>
    <message>
        <source>Invalid operation</source>
        <translation>Unzulässige Operation</translation>
    </message>
    <message>
        <source>Out of range</source>
        <translation>nicht im zulässigen Bereich</translation>
    </message>
    <message>
        <source>Unknown exception</source>
        <translation>Unbekannter Fehler</translation>
    </message>
</context>
<context>
    <name>gui::QSPdf</name>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Dokument befindet sich im Nur- Lesemodus</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Es trat ein unbekannter Fehler beim Speichern des Dokuments auf</translation>
    </message>
    <message>
        <source>Page not found</source>
        <translation>Seite wurde nicht gefunden</translation>
    </message>
    <message>
        <source>Unable to save:
%1</source>
        <translation>Außerstande zu speichern:
%1</translation>
    </message>
</context>
<context>
    <name>gui::RefPropertyDialog</name>
    <message>
        <source>Reference target</source>
        <translation>Referenvorgabe</translation>
    </message>
    <message>
        <source>Choose target for indirect reference</source>
        <translation></translation>
    </message>
    <message>
        <source>Object number</source>
        <translation>Objektnummer</translation>
    </message>
    <message>
        <source>Generation number</source>
        <translation>Versionsnummer</translation>
    </message>
    <message>
        <source>Reference target is not valid</source>
        <translation>Referenzvorgabe ist nicht zulässig</translation>
    </message>
</context>
<context>
    <name>gui::RevisionTool</name>
    <message>
        <source>Revision: </source>
        <translation>Änderung:</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>Linearisiertes PDF</translation>
    </message>
    <message>
        <source>No revisions</source>
        <translation>Keine Änderungen</translation>
    </message>
</context>
<context>
    <name>gui::SelectPagesDialog</name>
    <message>
        <source>Convert pdf to xml</source>
        <translation>Umwandeln von PDF in XML</translation>
    </message>
</context>
<context>
    <name>gui::Settings</name>
    <message>
        <source>Main Toolbar</source>
        <comment>MainToolbar</comment>
        <translation>Hauptwerkzeugleiste</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <comment>fload</comment>
        <translation>&amp;Öffnen...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <comment>fsave</comment>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <comment>opts</comment>
        <translation>&amp;Optionen</translation>
    </message>
    <message>
        <source>Close Window</source>
        <comment>closew</comment>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <source>Show/Hide &amp;commandline</source>
        <comment>hideCmd</comment>
        <translation>Anzeigen/Ausblenden &amp;Kommandozeile</translation>
    </message>
    <message>
        <source>Page Toolbar</source>
        <comment>PageToolbar</comment>
        <translation>Werkzeugleiste Seite</translation>
    </message>
    <message>
        <source>First Page</source>
        <comment>firstpage</comment>
        <translation>Erste Seite</translation>
    </message>
    <message>
        <source>Prev Page</source>
        <comment>prevpage</comment>
        <translation>Vorige Seite</translation>
    </message>
    <message>
        <source>Next Page</source>
        <comment>nextpage</comment>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <source>Last Page</source>
        <comment>lastpage</comment>
        <translation>Letzte Seite</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <comment>reloadpage</comment>
        <translation type="obsolete">Seite erneut Laden</translation>
    </message>
    <message>
        <source>Rotate page 270 degrees</source>
        <comment>rot-90</comment>
        <translation>Seite um 270 Grad drehen</translation>
    </message>
    <message>
        <source>Rotate page 90 degrees</source>
        <comment>rot90</comment>
        <translation>Seite um 90 Grad drehen</translation>
    </message>
    <message>
        <source>Edit page metrics</source>
        <comment>editPageMediaBox</comment>
        <translation>Seitenmaße bearbeiten</translation>
    </message>
    <message>
        <source>Add system font to page</source>
        <comment>addSystemFont</comment>
        <translation>Systemschriftart zu der Seite hinzufügen</translation>
    </message>
    <message>
        <source>Set page transformation matrix</source>
        <comment>setpagetm</comment>
        <translation>Setze die Seitenumwandlungsmatrix</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <comment>pagetext</comment>
        <translation>Text aus der Seite ausschneiden</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <comment>zoom_out</comment>
        <translation>Zoomen &amp;out</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <comment>zoom_in</comment>
        <translation>Zoomen &amp;in</translation>
    </message>
    <message>
        <source>Move page up</source>
        <comment>pageMoveUp</comment>
        <translation>Seite nach oben verschieben</translation>
    </message>
    <message>
        <source>Move page down</source>
        <comment>pageMoveDown</comment>
        <translation>Seite nach unten verschieben</translation>
    </message>
    <message>
        <source>Remove page</source>
        <comment>pageRemove</comment>
        <translation>Seite entfernen</translation>
    </message>
    <message>
        <source>Draw Toolbar</source>
        <comment>DrawToolbar</comment>
        <translation>Werkzeugleiste Zeichnen</translation>
    </message>
    <message>
        <source>Draw line</source>
        <comment>drawlinee</comment>
        <translation>Linie zeichnen</translation>
    </message>
    <message>
        <source>Draw arrow</source>
        <comment>drawarrowe</comment>
        <translation>Pfeil zeichnen</translation>
    </message>
    <message>
        <source>Draw rectangle</source>
        <comment>drawrecte</comment>
        <translation>Rechteck zeichnen</translation>
    </message>
    <message>
        <source>Add text</source>
        <comment>addtext</comment>
        <translation>Text einfügen</translation>
    </message>
    <message>
        <source>Strike through</source>
        <comment>striketrough</comment>
        <translation>Durchstreichen</translation>
    </message>
    <message>
        <source>Highlighting text</source>
        <comment>highlightingtext</comment>
        <translation>Text hervorheben</translation>
    </message>
    <message>
        <source>Revision Toolbar</source>
        <comment>RevisionToolbar</comment>
        <translation>Werkzeugleiste Überarbeitung</translation>
    </message>
    <message>
        <source>Revisions</source>
        <comment>revlabel</comment>
        <translation>Überarbeitungen</translation>
    </message>
    <message>
        <source>Operator Toolbar</source>
        <comment>OperatorToolbar</comment>
        <translation>Werkzeugleiste Operatoren</translation>
    </message>
    <message>
        <source>Set color</source>
        <comment>opsetcolor</comment>
        <translation>Farbe setzen</translation>
    </message>
    <message>
        <source>Set font</source>
        <comment>opsetfont</comment>
        <translation>Schriftart setzen</translation>
    </message>
    <message>
        <source>Set line width</source>
        <comment>opsetlinewidth</comment>
        <translation>Linienbreite setzen</translation>
    </message>
    <message>
        <source>Selection mode Toolbar</source>
        <comment>SelectionModeToolbar</comment>
        <translation>Werkeugleiste Auswahl</translation>
    </message>
    <message>
        <source>Select all objects</source>
        <comment>selectAllObjects</comment>
        <translation>Alle Objekte auswählen</translation>
    </message>
    <message>
        <source>Select graphical operators</source>
        <comment>selectGraphical</comment>
        <translation>Grafischen Operator auswählen</translation>
    </message>
    <message>
        <source>Select text</source>
        <comment>selectText</comment>
        <translation>Text auswählen</translation>
    </message>
    <message>
        <source>Select annotations</source>
        <comment>selectAnnot</comment>
        <translation>Anmerkungen auswählen</translation>
    </message>
    <message>
        <source>Text Toolbar</source>
        <comment>TextToolBar</comment>
        <translation>Werkzeugleiste Text</translation>
    </message>
    <message>
        <source>TreeView Toolbar</source>
        <comment>TreeViewToolbar</comment>
        <translation>Werkzeugleiste Baumansicht</translation>
    </message>
    <message>
        <source>Add object</source>
        <comment>treeAdditem</comment>
        <translation>Objekt hinzufügen</translation>
    </message>
    <message>
        <source>Delete object</source>
        <comment>treeDelitem</comment>
        <translation>Objekt löschen</translation>
    </message>
    <message>
        <source>Dynamic Toolbar</source>
        <comment>DynamicToolBar</comment>
        <translation>Dynamische Werkzeugleiste</translation>
    </message>
    <message>
        <source>Show all operators in stream</source>
        <comment>streamAll</comment>
        <translation>Alle Operatoren im Datenstrom anzeigen</translation>
    </message>
    <message>
        <source>Show only text operators in stream</source>
        <comment>streamText</comment>
        <translation>Nur Textoperatoren im Datenstrom anzeigen</translation>
    </message>
    <message>
        <source>Show only font operators in stream</source>
        <comment>streamFont</comment>
        <translation>Nur Schriftartenoperatoren im Datenstrom anzeigen</translation>
    </message>
    <message>
        <source>Show only graphical operators in stream</source>
        <comment>streamGfx</comment>
        <translation>Nur Grafikoperatoren im Datenstrom anzeigen</translation>
    </message>
    <message>
        <source>Main menu</source>
        <comment>MainMenu</comment>
        <translation>Hauptmenü</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <comment>filemenu</comment>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Save &amp;copy...</source>
        <comment>fsavecopy</comment>
        <translation type="obsolete">Speichern &amp;copy...</translation>
    </message>
    <message>
        <source>Save new &amp;revision</source>
        <comment>fsaverev</comment>
        <translation>Speichern als neue &amp;Revision</translation>
    </message>
    <message>
        <source>New &amp;Window</source>
        <comment>neww</comment>
        <translation>Neues &amp;Window</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <comment>quit</comment>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <comment>showmenu</comment>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Show/Hide &amp;property editor</source>
        <comment>hideProp</comment>
        <translation>Anzeigen/Ausblenden &amp;property editor</translation>
    </message>
    <message>
        <source>Show/Hide object &amp;tree</source>
        <comment>hideTree</comment>
        <translation>Anzeigen/Ausblenden Objekt &amp;tree</translation>
    </message>
    <message>
        <source>Show/Hide &amp;status bar</source>
        <comment>hideStatus</comment>
        <translation>Anzeigen/Ausblenden &amp;status bar</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <comment>searchText</comment>
        <translation>&amp;Text suchen</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <comment>toolsmenu</comment>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <source>&amp;Insert Pages from other document</source>
        <comment>mergeDoc</comment>
        <translation>&amp;Seiten aus einem anderen Dokument einfügen</translation>
    </message>
    <message>
        <source>&amp;Page</source>
        <comment>pagemenu</comment>
        <translation>&amp;Seite</translation>
    </message>
    <message>
        <source>Save page as image...</source>
        <comment>savepage</comment>
        <translation>Seite als Grafik speichern...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <comment>editopersmenu</comment>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>Set relative position of operator</source>
        <comment>opsetposop</comment>
        <translation>Relative Position des Operators setzen</translation>
    </message>
    <message>
        <source>Change relative position</source>
        <comment>opsetpos</comment>
        <translation>Relative Position verändern</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <comment>opsetdash</comment>
        <translation>Linienstrich-Stil setzen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>helpmenu</comment>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <comment>help_about</comment>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>help_index</comment>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Reload Page (show changes)</source>
        <comment>reloadpage</comment>
        <translation>Seite erneut laden (zeigt Änderungen)</translation>
    </message>
    <message>
        <source>PageRider Toolbar</source>
        <comment>PageRiderToolbar</comment>
        <translation>PageRider Werkzeugleiste</translation>
    </message>
    <message>
        <source>Save as text...</source>
        <comment>fsaveastext</comment>
        <translation>Als Text speichern...</translation>
    </message>
    <message>
        <source>&amp;Copy current revision</source>
        <comment>fcopyrevision</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::TreeItemPdf</name>
    <message>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Konturen</translation>
    </message>
</context>
<context>
    <name>gui::TreeWindow</name>
    <message>
        <source>Object</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Daten</translation>
    </message>
</context>
<context>
    <name>gui::Units</name>
    <message>
        <source>point</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <source>pt : point</source>
        <translation>pt : Punkt</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>Inch</translation>
    </message>
    <message>
        <source>inches</source>
        <translation>Inch</translation>
    </message>
    <message>
        <source>in : inch</source>
        <translation>in : Inch</translation>
    </message>
    <message>
        <source>mil : milli-inch</source>
        <translation>mil : Tausendstel Inch</translation>
    </message>
    <message>
        <source>hands</source>
        <translation>Hände</translation>
    </message>
    <message>
        <source>hand</source>
        <translation>Hand</translation>
    </message>
    <message>
        <source>hand : hand</source>
        <translation>hand : Hand</translation>
    </message>
    <message>
        <source>foot</source>
        <translation>Fuß</translation>
    </message>
    <message>
        <source>feet</source>
        <translation>Füße</translation>
    </message>
    <message>
        <source>ft : foot</source>
        <translation>ft : Fuß</translation>
    </message>
    <message>
        <source>link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>links</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>li : link</source>
        <translation>li : Link</translation>
    </message>
    <message>
        <source>yard</source>
        <translation>Yard (Schritt)</translation>
    </message>
    <message>
        <source>yards</source>
        <translation>Yards (Schritte)</translation>
    </message>
    <message>
        <source>yd : yard</source>
        <translation>yd : Yard (Schritt)</translation>
    </message>
    <message>
        <source>rod</source>
        <translation>Rod (Rute)</translation>
    </message>
    <message>
        <source>rods</source>
        <translation>Rods (Ruten)</translation>
    </message>
    <message>
        <source>pole</source>
        <translation>Pol</translation>
    </message>
    <message>
        <source>poles</source>
        <translation>Pole</translation>
    </message>
    <message>
        <source>perch</source>
        <translation>Perch</translation>
    </message>
    <message>
        <source>perches</source>
        <translation>Perch</translation>
    </message>
    <message>
        <source>rd : rod (pole, perch)</source>
        <translation>rd : rod (Pole, Perch)</translation>
    </message>
    <message>
        <source>fathom</source>
        <translation>Faden, Klafter</translation>
    </message>
    <message>
        <source>fathoms</source>
        <translation>Fäden, Klafter</translation>
    </message>
    <message>
        <source>fm. : fathom</source>
        <translation>fm : Faden, Klafter</translation>
    </message>
    <message>
        <source>chain</source>
        <translation>Kette</translation>
    </message>
    <message>
        <source>chains</source>
        <translation>Ketten</translation>
    </message>
    <message>
        <source>ch : chain</source>
        <translation>ch : Kette</translation>
    </message>
    <message>
        <source>furlong</source>
        <translation>Furlong</translation>
    </message>
    <message>
        <source>furlongs</source>
        <translation>Furlonge</translation>
    </message>
    <message>
        <source>fur. : furlong</source>
        <translation>fur. : Furlong</translation>
    </message>
    <message>
        <source>cable</source>
        <translation>Kabel</translation>
    </message>
    <message>
        <source>cable : cable</source>
        <translation>cable : Kabel</translation>
    </message>
    <message>
        <source>mile</source>
        <translation>Meile</translation>
    </message>
    <message>
        <source>miles</source>
        <translation>Meilen</translation>
    </message>
    <message>
        <source>mi : mile</source>
        <translation>ml : Meile</translation>
    </message>
    <message>
        <source>land</source>
        <translation>Land</translation>
    </message>
    <message>
        <source>lands</source>
        <translation>Land</translation>
    </message>
    <message>
        <source>league</source>
        <translation>League</translation>
    </message>
    <message>
        <source>leagues</source>
        <translation>Leagues</translation>
    </message>
    <message>
        <source>land : land (league)</source>
        <translation>land : Land (League)</translation>
    </message>
    <message>
        <source>m : meter</source>
        <translation>m : Meter</translation>
    </message>
    <message>
        <source>Ym : yottameter</source>
        <translation>Ym : Yottameter</translation>
    </message>
    <message>
        <source>Zm : zettameter</source>
        <translation>Zm : Zettameter</translation>
    </message>
    <message>
        <source>Em : exameter</source>
        <translation>Em : Exameter</translation>
    </message>
    <message>
        <source>Pm : petameter</source>
        <translation>PM : Petameter</translation>
    </message>
    <message>
        <source>Tm : terameter</source>
        <translation>Tm : Terameter</translation>
    </message>
    <message>
        <source>Gm : gigameter</source>
        <translation>Gm : Gigameter</translation>
    </message>
    <message>
        <source>Mm : megameter</source>
        <translation>Mm : Megameter</translation>
    </message>
    <message>
        <source>km : kilometer</source>
        <translation>km : Kilometer</translation>
    </message>
    <message>
        <source>hm : hectometer</source>
        <translation>hm : Hektometer (100 Meter)</translation>
    </message>
    <message>
        <source>dam : decameter</source>
        <translation>dam : Decameter</translation>
    </message>
    <message>
        <source>dm : decimeter</source>
        <translation>dm : Dezimeter (0,1m)</translation>
    </message>
    <message>
        <source>cm : centimeter</source>
        <translation>cm : Zentimeter</translation>
    </message>
    <message>
        <source>mm : millimeter</source>
        <translation>mm : Millimeter</translation>
    </message>
    <message>
        <source>um : micrometer</source>
        <translation>um : Micrometer</translation>
    </message>
    <message>
        <source>nm : nanometer</source>
        <translation>nm : Nanometer</translation>
    </message>
    <message>
        <source>pm : picometer</source>
        <translation>pm : Picometer</translation>
    </message>
    <message>
        <source>fm : femtometer</source>
        <translation>fm : femtometer</translation>
    </message>
    <message>
        <source>am : attometer</source>
        <translation>am :  Attometer</translation>
    </message>
    <message>
        <source>zm : zeptometer</source>
        <translation>zm :  Zeptometer</translation>
    </message>
    <message>
        <source>ym : yoctometer</source>
        <translation>ym : Yoktometer</translation>
    </message>
    <message>
        <source>A : angstrom</source>
        <translation>A :  Angstrom</translation>
    </message>
    <message>
        <source>astronomical unit</source>
        <translation>Astronomische Einheit</translation>
    </message>
    <message>
        <source>astronomical units</source>
        <translation>Astronomische Einheiten</translation>
    </message>
    <message>
        <source>AU : astronomical unit</source>
        <translation>AU : Astronomische Einheit</translation>
    </message>
    <message>
        <source>light year</source>
        <translation>Lichtjahr</translation>
    </message>
    <message>
        <source>light years</source>
        <translation>Lichtjahre</translation>
    </message>
    <message>
        <source>ly : light year</source>
        <translation>ly : Lichtjahre</translation>
    </message>
    <message>
        <source>parsec</source>
        <translation>Parsec</translation>
    </message>
    <message>
        <source>pc : parsec</source>
        <translation>pc : Parsec</translation>
    </message>
    <message>
        <source>nautical mile</source>
        <translation>Seemeile</translation>
    </message>
    <message>
        <source>nautical miles</source>
        <translation>Seemeilen</translation>
    </message>
    <message>
        <source>n.m. : nautical mile</source>
        <translation>n.m. : Seemeile</translation>
    </message>
</context>
</TS>
